## 0.12.4 (2025-08-15)

### Pull Requests

-  [`eb53657`](https://github.com/JenspederM/kedro-databricks/commit/eb53657765cecd4468de1fea7b418dde3e28b2dc): [ puneeter/fix/tests](https://github.com/JenspederM/kedro-databricks/pull/144)
-  [`f8a4d13`](https://github.com/JenspederM/kedro-databricks/commit/f8a4d13617824dc3f3c60df6bcfd740ec396530a): [ JenspederM/docs/contributing](https://github.com/JenspederM/kedro-databricks/pull/141)
-  [`b48c57d`](https://github.com/JenspederM/kedro-databricks/commit/b48c57df1049898b44db462489c4cfa04922035c): [ puneeter/fix/minor-bugs](https://github.com/JenspederM/kedro-databricks/pull/143)

### Fix

-  [`e5f74a4`](https://github.com/JenspederM/kedro-databricks/commit/e5f74a4714200e267869a1589278719d9b70a0fd):  Tests support different providers and updated asserts
-  [`a292a2f`](https://github.com/JenspederM/kedro-databricks/commit/a292a2f4a37d7ef6b9653f369d98e0db6c08aa93):  Fix tests
-  [`149196b`](https://github.com/JenspederM/kedro-databricks/commit/149196b6eb983a65ae784900a0e695fdd8892d86):  unit tests
-  [`fdc6901`](https://github.com/JenspederM/kedro-databricks/commit/fdc690153ed4c9485926774f5155ecea2e9c4cc0):  minor bugs in bundle

### Other Changes

-  [`388181f`](https://github.com/JenspederM/kedro-databricks/commit/388181f23bbb9fa19a5d063583ef2e98676586e2):  we run format during lint
-  [`47bfeff`](https://github.com/JenspederM/kedro-databricks/commit/47bfeff09cc27a15fa7534b81ed02d7e010235bc):  we also want to format
-  [`9011612`](https://github.com/JenspederM/kedro-databricks/commit/901161217f36317758bdf04ba1d300e965dd59f9):  change titles
-  [`adef928`](https://github.com/JenspederM/kedro-databricks/commit/adef92844af651e9c0d3690ec3f2f7967704ae9e):  add contribute to nav
-  [`821d3c2`](https://github.com/JenspederM/kedro-databricks/commit/821d3c2b7f683d7bca2935345e25155d470ee0a8):  we want contributing on website
-  [`8e7dd06`](https://github.com/JenspederM/kedro-databricks/commit/8e7dd06d2d0ff9f53c59c38ff3906d2bda410377):  use uv for linting
-  [`8b6214d`](https://github.com/JenspederM/kedro-databricks/commit/8b6214d4ee9a8285b9466dad835efeeb3d3127cb):  reference contributing in readme
-  [`d77a180`](https://github.com/JenspederM/kedro-databricks/commit/d77a1800646e6a48ffb6c2d499c6f1c4de00c31a):  add contributing.md

[main db663be] bump: version 0.12.3 → 0.12.4
 3 files changed, 28 insertions(+), 2 deletions(-)

